package fr.sanchezm.attestationsCovid19.ui.add

import android.content.Intent
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.databinding.DataBindingUtil
import androidx.fragment.app.Fragment
import androidx.lifecycle.Observer
import androidx.lifecycle.ViewModelProvider
import com.google.android.material.snackbar.Snackbar
import fr.sanchezm.attestationsCovid19.QrCodeActivity
import fr.sanchezm.attestationsCovid19.R
import fr.sanchezm.attestationsCovid19.databinding.FragmentAddAttestationBinding
import fr.sanchezm.attestationsCovid19.utilities.InjectorUtils

class AddFragment : Fragment() {

    private lateinit var addViewModel: AddViewModel

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        initializeUi()
        val binding = DataBindingUtil.inflate<FragmentAddAttestationBinding>(
            inflater,
            R.layout.fragment_add_attestation,
            container,
            false
        ).apply {
            this.lifecycleOwner = this@AddFragment
            this.viewModel = addViewModel
        }


        bindMessage(binding.constraintContext)
        return binding.root
    }

    private fun bindMessage(ctx: View) {
        addViewModel.errorMessage.observe(viewLifecycleOwner, Observer {
            it.getContentIfNotHandled()?.let { stringId ->
                Snackbar.make(ctx, stringId, Snackbar.LENGTH_SHORT).show()
            }
        })

        addViewModel.dataMessage.observe(viewLifecycleOwner, Observer {
            it.getContentIfNotHandled()?.let { stringId ->
                Snackbar.make(ctx, stringId, Snackbar.LENGTH_SHORT).show()
            }
        })

        addViewModel.startActivity.observe(viewLifecycleOwner, Observer { event ->
            event.getContentIfNotHandled()?.let {
                val intent = Intent(context, QrCodeActivity::class.java).apply {
                    putExtra("createAt", it)
                    putExtra("toCreate", true)
                }
                startActivity(intent)
            }
        })
    }

    private fun initializeUi() {
        val factory = context?.let { InjectorUtils.provideAddViewModelFactory(it) }
        addViewModel = factory?.let {
            ViewModelProvider(this, it)
                .get(AddViewModel::class.java)
        }!!
    }
}
