package fr.sanchezm.attestationsCovid19.ui.qrcode

import android.content.Intent
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.databinding.DataBindingUtil
import androidx.fragment.app.Fragment
import androidx.lifecycle.Observer
import androidx.lifecycle.ViewModelProvider
import fr.sanchezm.attestationsCovid19.PdfViewerActivity
import fr.sanchezm.attestationsCovid19.R
import fr.sanchezm.attestationsCovid19.databinding.QrCodeFragmentBinding
import fr.sanchezm.attestationsCovid19.utilities.InjectorUtils
import kotlinx.android.synthetic.main.qr_code_fragment.*

class QrCodeFragment : Fragment() {

    companion object {
        fun newInstance() = QrCodeFragment()
    }

    private lateinit var qrCodeViewModel: QrCodeViewModel

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        arguments?.getBoolean("toCreate", false)?.let {
            arguments?.getLong("createAt", 0)?.let { it1 ->
                initializeUi(
                    it1,
                    it
                )
            }
        }
        val binding = DataBindingUtil.inflate<QrCodeFragmentBinding>(
            inflater,
            R.layout.qr_code_fragment,
            container,
            false
        ).apply {
            this.lifecycleOwner = this@QrCodeFragment
            this.viewModel = qrCodeViewModel
        }

        bindingData()

        return binding.root
    }

    private fun initializeUi(createAt: Long, toCreate: Boolean) {
        val factory = context?.let { InjectorUtils.provideQrCodeViewModel(it) }
        qrCodeViewModel = factory?.let {
            ViewModelProvider(this, it)
                .get(QrCodeViewModel::class.java)
        }!!
        qrCodeViewModel.addData(createAt, toCreate)
    }

    private fun bindingData() {
        qrCodeViewModel.qrCodeBitmap.observe(viewLifecycleOwner, Observer {
            qrcode_image.setImageBitmap(it)
        })

        qrCodeViewModel.finish.observe(viewLifecycleOwner, Observer { event ->
            event.getContentIfNotHandled()?.let {
                if (it) {
                    activity?.finish()
                }
            }
        })

        qrCodeViewModel.startActivity.observe(viewLifecycleOwner, Observer { event ->
            event.getContentIfNotHandled()?.let {
                val intent = Intent(context, PdfViewerActivity::class.java).apply {
                    putExtra("createAt", it)
                    putExtra("toCreate", true)
                }
                startActivity(intent)
            }
        })
    }

}
